# Generated by Django 3.1.7 on 2021-03-29 06:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('rest_framework_reactive', '0003_reduce_complexity'),
    ]

    operations = [
        migrations.AlterField(
            model_name='item',
            name='data',
            field=models.JSONField(),
        ),
    ]
